auxjad
======

|PyPI| |Build| |Python versions| |License|  |Bug report|

Auxiliary functions and classes for Abjad 3.1. All classes and functions have a
`__doc__` attribute with usage instructions.

Documentation is available at https://gilbertohasnofb.github.io/auxjad-docs/.
A pdf version of the documentation is also available in the `docs` directory.

Bugs can be reported to https://github.com/gilbertohasnofb/auxjad/issues.

This library is published under the MIT License.

.. |PyPI| image:: https://img.shields.io/pypi/v/auxjad.svg
   :target: https://pypi.python.org/pypi/auxjad
.. |Build| image:: https://travis-ci.org/gilbertohasnofb/auxjad.svg?branch=master
   :target: https://travis-ci.org/gilbertohasnofb/auxjad
.. |Python versions| image:: https://img.shields.io/pypi/pyversions/auxjad.svg
.. |License| image:: https://img.shields.io/github/license/gilbertohasnofb/auxjad.svg
   :target: https://github.com/gilbertohasnofb/auxjad/blob/master/LICENSE
.. |Bug report| image:: https://img.shields.io/badge/bug-report-red.svg
   :target: https://github.com/gilbertohasnofb/auxjad/issues
